@@ -6,6 +6,8 @@
 #' Plot a colourlovers PNG image in a new plotting window.
 #' 
 #' @param x A colourlovers color, palette, or pattern object.
+#' @param ask A boolean indicating if plots should be presented interactively 
+#'   or all at once (default is \code{FALSE}).
 #' @param \dots Ignored.
 #' 
 #' @return The \code{x} object is invisibly returned.
@@ -19,7 +21,7 @@
 #' 
 #' @examples \dontrun{
 #' # Plot a color clpng
-#' co <- clcolor(rgb(0,0,1))
+#' co <- clcolor(rgb(0, 0, 1))
 #' plot(co)
 #' 
 #' # Plot a pattern clpng
@@ -38,7 +40,7 @@
 #' plot(p, type = 'pie')  # pie chart swatches
 #' }
 #' 
-clpng <- function(x, ...) {
+clpng <- function(x, ask = TRUE, ...) {
     # extract an imageUrl from a COLOURlovers object and print a clpng
     s1 <- inherits(x, 'clcolor') | inherits(x, 'clpalette') | inherits(x, 'clpattern')
     s2 <- inherits(x, 'clcolors') | inherits(x, 'clpalettes') | inherits(x, 'clpatterns')
@@ -50,24 +52,24 @@ clpng <- function(x, ...) {
         else
             par(mar = c(1, 1, 2, 1))
     } else if (s2) {
-        if (inherits(x, 'clpalette'))
-            par(mar = c(2, 1, 2, 1), ask = TRUE)
+        if (inherits(x, 'clpalettes'))
+            par(mar = c(2, 1, 2, 1), ask = ask)
         else
-            par(mar = c(1, 1, 2, 1), ask = TRUE)
+            par(mar = c(1, 1, 2, 1), ask = ask)
         sapply(x, clpng)
         return(invisible(x))
     }
     
     tmp <- tempfile()
     download.file(u, tmp, quiet = TRUE, mode = 'wb')
+    
+    m <- ''
     if (inherits(x, 'clcolor')) {
         m <- paste('Color #', x$hex, sep = '')
     } else if (inherits(x, 'clpalette')) {
         m <- paste('Palette #', x$id, sep = '')
     } else if (inherits(x, 'clpattern')) {
         m <- paste('Pattern #', x$id, sep = '')
-    } else {
-        m <- ''
     }
     
     plot(1:2, type = 'n', bty = 'n', xlab = '', ylab = '',
@@ -75,7 +77,7 @@ clpng <- function(x, ...) {
     rasterImage(readPNG(tmp), 1, 1, 2, 2)
     
     if (inherits(x, 'clpalette')) {
-        axis(1, seq(1, 2, length.out = 5), unlist(x$colors))
+        axis(1, seq(1, 2, length.out = length(unlist(x$colors))), unlist(x$colors))
     }
     file.remove(tmp)
     
@@ -84,7 +86,7 @@ clpng <- function(x, ...) {
 
 #' @rdname clpng
 #' @export
-clpie <- function(x, ...) {
+clpie <- function(x, ask = TRUE, ...) {
     # extract colors a COLOURlovers object and print a pie of them
     s1 <- inherits(x, 'clcolor') | inherits(x, 'clpalette') | inherits(x, 'clpattern')
     s2 <- inherits(x, 'clcolors') | inherits(x, 'clpalettes') | inherits(x, 'clpatterns')
@@ -93,21 +95,20 @@ clpie <- function(x, ...) {
         u <- swatch(x)[[1]]
         par(mar = c(1, 1, 2, 1))
         
+        m <- ''
         if (inherits(x, 'clcolor')) {
             m <- paste('Color #', x$hex, sep = '')
         } else if (inherits(x, 'clpalette')) {
             m <- paste('Palette #', x$id, sep = '')
         } else if (inherits(x, 'clpattern')) {
             m <- paste('Pattern #', x$id, sep = '')
-        } else{
-            m <- ''
         }
         
         pie(rep(1, length(u)), labels = u, border = NA, col = u, main = m)
         
         return(invisible(x))
     } else if (s2) {
-        par(mar = c(1, 1, 2, 1), ask = TRUE)
+        par(mar = c(1, 1, 2, 1), ask = ask)
         sapply(x, clpie)
         return(invisible(x))
     }
